"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DEFAULT_IMPORTS = void 0;
exports.generateCodePushupConfig = generateCodePushupConfig;
const devkit_1 = require("@nx/devkit");
const path = require("node:path");
const utils_js_1 = require("./utils.js");
exports.DEFAULT_IMPORTS = [
    "import type { CoreConfig } from '@code-pushup/models';",
];
function generateCodePushupConfig(tree, root, options) {
    const supportedFormats = ['ts', 'mjs', 'js'];
    const firstExistingFormat = supportedFormats.find(ext => tree.exists(path.join(root, `code-pushup.config.${ext}`)));
    if (firstExistingFormat) {
        devkit_1.logger.warn(`NOTE: No config file created as code-pushup.config.${firstExistingFormat} file already exists.`);
    }
    else {
        const { fileImports: rawImports, persist, upload, plugins: rawPlugins = [], // plugins are required
        categories: rawCategories, } = options ?? {};
        const plugins = rawPlugins.map(utils_js_1.normalizeExecutableCode);
        const categories = rawCategories?.map(utils_js_1.normalizeExecutableCode);
        const configFileImports = [
            ...(rawImports ? (0, utils_js_1.normalizeItemOrArray)(rawImports) : exports.DEFAULT_IMPORTS),
            ...plugins.flatMap(({ fileImports }) => fileImports),
            ...(categories ?? []).flatMap(({ fileImports }) => fileImports),
        ];
        (0, devkit_1.generateFiles)(tree, path.join(__dirname, 'files'), root, {
            ...options,
            fileImports: (0, utils_js_1.formatArrayToLinesOfJsString)(configFileImports),
            persist: (0, utils_js_1.formatObjectToFormattedJsString)(persist),
            upload: (0, utils_js_1.formatObjectToFormattedJsString)(upload),
            plugins: `[${plugins.map(({ codeStrings }) => codeStrings).join(',')}]`,
            categories: categories &&
                `[${categories.map(({ codeStrings }) => codeStrings).join(',')}]`,
        });
    }
}
//# sourceMappingURL=code-pushup-config.js.map